Function tuxedo_template_wallet::timestamp::get_timestamp
source · pub(crate) fn get_timestamp(db: &Db) -> Result<u64>Expand description
Apply a transaction to the local database, storing the new timestamp.
pub(crate) fn get_timestamp(db: &Db) -> Result<u64>Apply a transaction to the local database, storing the new timestamp.